
;########################################
;#					#
;#	Example: SW_led -  light LEd with Switch press. #
;#	by Axiom - RDF 			#
;########################################

LED1:      equ  $04       ; LED 3 select
LED2:      equ  $08       ; LED 4 select

SW1:	equ	$40	; Sw1 input bit
SW2:	equ	$80	; switch 2 input bit


REGBS           EQU $0000      ; C32 register bank base address
#include        c32reg.asm     ; include register equates


; Define Ram use....
;..................................................................
; Define Ram based Interrupt vector table for AutoStart...
; HC12 DP256 table...

	ORG	$0F8A
V_TBL:
VSRV		RMB	2	; RESERVED, VECTOR SERVICE VARIABLE
VPWME		RMB	2	; 8C PWM Emergency shutdown
VPTPI		RMB	2	; 8E Port P input
VC4TX		RMB	2	; 90 CAN4 Transmit
VC4RX		RMB	2	; 92 CAN4 Receive
VC4ERR		RMB	2	; 94 CAN4 Error
VC4WU		RMB	2	; 96 CAN4 wakeup
VC3TX		RMB	2	; 98 CAN3 Transmit
VC3RX		RMB	2	; 9A CAN3 Receive
VC3ERR		RMB	2	; 9C CAN3 Error
VC3WU		RMB	2	; 9E CAN3 wakeup
VC2TX		RMB	2	; A0 CAN2 Transmit
VC2RX		RMB	2	; A2 CAN2 Receive
VC2ERR		RMB	2	; A4 CAN2 Error
VC2WU		RMB	2	; A6 CAN2 wakeup
VC1TX		RMB	2	; A8 CAN1 Transmit
VC1RX		RMB	2	; AA CAN1 Receive
VC1ERR		RMB	2	; AC CAN1 Error
VC1WU		RMB	2	; AE CAN1 wakeup
VC0TX		RMB	2	; B0 CAN0 Transmit
VC0RX		RMB	2	; B2 CAN0 Receive
VC0ERR		RMB	2	; B4 CAN0 Error
VC0WU		RMB	2	; B6 CAN0 wakeup
VFEE		RMB	2	; B8 Flash
VEEP		RMB	2	; BA EEprom
VSPI2		RMB	2	; BC SPI2
VSPI1		RMB	2	; BE SPI1
VI2C		RMB	2	; C0 IIC
VBDLC		RMB	2	; C2 BDLC
VCRGC		RMB	2	; C4 CRG self clock
VCRGL		RMB	2	; C6 CRG Lock
VPABO		RMB	2	; C8 Pulse count B overflow
VMCNT		RMB	2	; CA Modulus counter
VPTHI		RMB	2	; CC Port H input
VPTJI		RMB	2	; CE Port J input
VADC1		RMB	2	; D0 ADC1
VADC0		RMB	2	; D2 ADC0
VSCI1		RMB	2	; D4 SCI1
VSCI0		RMB	2	; D6 SCI0
VSPI0		RMB	2	; D8 SPI0
VPAAI		RMB	2	; DA Pulse count A input
VPAAO		RMB	2	; DC Pulse count A overflow
VTOF		RMB	2	; DE Timer overflow
VTC7		RMB	2	; E0 TC7
VTC6		RMB	2	; E2 TC6
VTC5		RMB	2	; E4 TC5
VTC4		RMB	2	; E6 TC4
VTC3		RMB	2	; E8 TC3
VTC2		RMB	2	; EA TC2
VTC1		RMB	2	; EC TC1
VTC0		RMB	2	; EE TC0
VRTI		RMB	2	; F0 RTI
VIRQ		RMB	2	; F2 IRQ
VXIRQ		RMB	2	; F4 XIRQ
VSWI		RMB	2	; F6 SWI
VTRAP		RMB	2	; F8 TRAP
VCOP		RMB	2	; FA COP
VCLM		RMB	2	; FC Clock
ENDVECT EQU   *

;..................................................................
; Define Stack location, under vector table...

STACK	EQU	$0F8A			; top of ram under Interrupt vectors

;..................................................................
; Define user variables here...



;******************************************************************
; Define Program start location, internal ram memory...

	ORG	$800

; Program start-up example .....

RESET:
	sei				; Interrupts off! in case of trap here

	LDS     #STACK		; initialize the stack pointer
	CLR     COPCTL		; COP TIMER OFF

; Initialize Interrupt vectors....
	MOVW	#RESET,VCLM		; set clock fail to Reset vector
					; Set all other not applied interrupt vectors
					; to Reset or Monitor may trap as an
					; unscheduled interrupt and application
					; will not recover without user intervention

; add other initialization as needed by application...

; prepare LED output port...
	clr	PTS		; clear port s data
	movb	#$0c,DDRS	; LED drive pins 2 and 3 = output

; Prepare Switch input port...
	clr	DDRJ		; port pins 6 and 7 = input with pull-ups
	clr	PPSJ		; pull-ups selected
	movb	#$c0,PERJ	; pull-ups on

; Start user program...

GO:
	ldaa	PTJ 		; read the switch port
	bita	#SW1		; test if switch 1 pressed
	bne	GO1		; if not, branch
	bset	PTS,LED1		; LED1 is on
	bra	GO2		; branch to GO2
GO1:
	bclr	PTS,LED1	; LED1 is off
GO2:
	bita	#SW2		; test if switch 2 is on
	bne	GO3		; if not, branch
	bset	PTS,LED2		; if so, indicate on LED 2
	bra	GO		; branch to top, GO
GO3:
	bclr	PTS,LED2	; led 2 is off
	bra	GO		; loop


